--- title: Feedback --- # Feedback If Outlines has been helpful to you, let us know on [Discord][discord] or give us a shoutout on [Twitter][twitter]! It's always heartwarming ❤️

> I am once again reminding you that structured extraction using LLMs is going to transform every single industry in the next 10 years https://t.co/xQ3tcWnrZ8

> — Sam Hogan (@0xSamHogan) April 17, 2024

> outline's growth is insane, using is an understatement! https://t.co/rHCNWhZdCs

> — jason liu (@jxnlco) April 17, 2024

> Outlines is an amazing lib and more popular than @remilouf’s modesty will admit. https://t.co/DfHbMPIlX1 https://t.co/mDHIWJrD0C

> — Delip Rao e/σ (@deliprao) April 18, 2024

> Impressive implementation of a true regex / json / grammar guided text generation pic.twitter.com/RX5RVYaVIx

> — Rohan Paul (@rohanpaul_ai) December 30, 2023

> Most underrated Github Repo in AI + LLM JSON guided Generation: https://t.co/lSB8KIet1H

> — 🎙Jean-Louis Queguiner (@JiliJeanlouis) December 18, 2023

> Nice and useful. https://t.co/LX72AE0lgt

> — Dan Roy (@roydanroy) August 15, 2023

> HUGE dub for open source AI https://t.co/bYKuiEUZ1j

> — kenneth 🖇 (@k3nnethfrancis) August 15, 2023

> This is amazing - glad to see more outp guidance modules!
> Will try this out soon I'm wondering how they translate from regex automatons to token boundaries
> Also why Open Source will succeed. Even today I don't see any guided output functionality from the big providers. https://t.co/Ity2H25Klf

> — Hrishi (@hrishioa) August 14, 2023

> Outlines - a library to help LLM developers guide text generation in a fast and reliable way.
> "Provides generation methods that guarantee that the output will match a regular expressions, or follow a JSON schema."
> Need to check this out. Reliable JSON output is a common use… pic.twitter.com/Bkbh8vKogN

> — elvis (@omarsar0) August 14, 2023

> Woah this is cool! Makes open source models more usable.
> Give any LLM Function Call capability (and more) with Outlines: https://t.co/PtPykR5ZGR https://t.co/RRQjWHnIxv pic.twitter.com/BwNnH8SMwv

> — Yohei (@yoheinakajima) August 14, 2023

> This is awesome! Being able to guarantee the output's structure unblocks so many applications. This is a great milestone and a fundamental building block for more advanced AI apps. https://t.co/WdwMOc7hE8

> — Guilherme Castro (@skastr052) August 15, 2023

> Juggling with the unpredictable outputs of ChatGPT API lately while building my product. 😓
> Tried prompt engineering to channel its wisdom into a neat JSON, but it's like asking a cat to fetch. 🐱
> Luckily, stumbled upon "Outlines" – looks like a promising way to tame the LLM… pic.twitter.com/oYQ6q8exAS

> — Charlie (@14435635Sun) August 15, 2023

> A complex system of LLM input-outputs interacting with non-LLM agents and models benefits immeasurably from structured outputs. The outlines package saves so much time, https://t.co/NhVQ6NpKDR

> — Amir Sani (@amirsani) November 26, 2023

# Let us know! We highly value the insights of our users, and we would love to hear from you. If you are using Outlines for your projects and would like to share your experience with us, let's connect: - What are you building with it? - What do you like about it? - What challenges are you facing? - What do you think could be improved? To schedule an appointment follow [this link](https://cal.com/dottxt/outlines). This is exclusively intended to share your experience, please go on [Discord][discord] or [GitHub](https://github.com/dottxt-ai/outlines/discussions) for support. [discord]: https://discord.gg/UppQmhEpe8 [twitter]: https://twitter.com/dottxtai